from uipyqt2 import *

__author__ = "brauser_vekato"
__version__ = "0.2.6"
__email__ = "vovbon6767@gmail.com"